@@ -13,6 +13,9 @@ use Module::Load::Conditional   qw[can_load];
 use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 use version;
 
+use vars qw[$VERSION];
+$VERSION = "0.9140";
+
 $Params::Check::VERBOSE = 1;
 
 ### for the version ###
@@ -509,12 +512,13 @@ sub _send_report {
         $message .= REPORT_TESTS_SKIPPED->();
     } elsif( $grade eq GRADE_NA) {
 
+        my $capture = ( $status && defined $status->{capture} ? $status->{capture} : $buffer );
+
         ### add the reason for the NA to the buffer
-        $buffer = join $/, $buffer, map {
+        $capture = join $/, $capture, map {
                         '[' . $_->tag . '] [' . $_->when . '] ' .
                         $_->message } ( CPANPLUS::Error->stack )[-1];
 
-        my $capture = ( $status && defined $status->{capture} ? $status->{capture} : $buffer );
         ### the bit where we inform what went wrong
         $message .= REPORT_MESSAGE_FAIL_HEADER->( $stage, $capture );
 
